"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BearerTokenVerifyProvider = void 0;
const tslib_1 = require("tslib");
const berrors_1 = require("berrors");
const moment_timezone_1 = tslib_1.__importDefault(require("moment-timezone"));
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const core_1 = require("@loopx/core");
const providers_1 = require("../../../providers");
const repositories_1 = require("../../../repositories");
let BearerTokenVerifyProvider = exports.BearerTokenVerifyProvider = class BearerTokenVerifyProvider {
    constructor(revokedTokenRepository, logger, jwtVerifier) {
        this.revokedTokenRepository = revokedTokenRepository;
        this.logger = logger;
        this.jwtVerifier = jwtVerifier;
    }
    value() {
        return async (token, req) => {
            const isRevoked = await this.revokedTokenRepository.get(token);
            if (isRevoked === null || isRevoked === void 0 ? void 0 : isRevoked.token) {
                throw new core_1.AuthErrors.TokenRevoked();
            }
            let user;
            try {
                user = await this.jwtVerifier(token, {
                    issuer: process.env.JWT_ISSUER,
                    algorithms: ['HS256'],
                });
            }
            catch (error) {
                this.logger.error(JSON.stringify(error));
                throw new berrors_1.BErrors.Unauthorized('TokenExpired');
            }
            if (user.passwordExpiryTime && (0, moment_timezone_1.default)().isSameOrAfter((0, moment_timezone_1.default)(user.passwordExpiryTime))) {
                throw new core_1.AuthErrors.PasswordExpiryError();
            }
            return user;
        };
    }
};
exports.BearerTokenVerifyProvider = BearerTokenVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.RevokedTokenRepository)),
    tslib_1.__param(1, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(2, (0, context_1.inject)(providers_1.AuthCodeBindings.JWT_VERIFIER)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.RevokedTokenRepository, Object, Function])
], BearerTokenVerifyProvider);
//# sourceMappingURL=bearer-token-verify.provider.js.map