"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OtpVerifyProvider = void 0;
const tslib_1 = require("tslib");
const otplib_1 = require("otplib");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const authentication_1 = require("@bleco/authentication");
const core_2 = require("@loopx/core");
const models_1 = require("../../../models");
const otp_1 = require("../../../otp/otp");
const repositories_1 = require("../../../repositories");
const otp_service_1 = require("../../../services/otp.service");
let OtpVerifyProvider = exports.OtpVerifyProvider = class OtpVerifyProvider {
    constructor(userRepository, otpCacheRepo, client, otpService, logger) {
        this.userRepository = userRepository;
        this.otpCacheRepo = otpCacheRepo;
        this.client = client;
        this.otpService = otpService;
        this.logger = logger;
    }
    value() {
        return async (uci, otp) => {
            let request = otp_1.OtpRequest.from(uci);
            const userPropKey = request ? request.key : 'username';
            const userPropValue = request ? request.upn : uci;
            const user = (await this.userRepository.findOne({
                where: {
                    [userPropKey]: userPropValue,
                },
            }));
            if (!user) {
                this.logger.error(`Invalid OTP Request. Cannot find user with {${userPropKey}: "${userPropValue}"}`);
                throw new authentication_1.AuthenticationErrors.InvalidCredentials();
            }
            if (!request) {
                request = otp_1.OtpRequest.fromUser(user, uci);
            }
            request.user = user;
            // sender
            if (!otp) {
                await this.otpService.sendOtp(request, this.client);
                return user;
            }
            // verifier
            const otpCache = await this.otpCacheRepo.get(request.uci);
            if (!otpCache) {
                this.logger.error('Invalid OTP Request');
                throw new authentication_1.AuthenticationErrors.OtpExpired();
            }
            let isValid = false;
            try {
                if (otpCache.otpSecret)
                    isValid = otplib_1.totp.check(otp, otpCache.otpSecret);
            }
            catch (err) {
                this.logger.error(err);
                throw new authentication_1.AuthenticationErrors.InvalidCredentials();
            }
            if (!isValid) {
                throw new authentication_1.AuthenticationErrors.OtpInvalid();
            }
            return user;
        };
    }
};
exports.OtpVerifyProvider = OtpVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.OtpCacheRepository)),
    tslib_1.__param(2, (0, context_1.inject)(authentication_1.AuthenticationBindings.CURRENT_CLIENT)),
    tslib_1.__param(3, (0, core_1.service)(otp_service_1.OtpService)),
    tslib_1.__param(4, (0, context_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.UserRepository,
        repositories_1.OtpCacheRepository,
        models_1.AuthClient,
        otp_service_1.OtpService, Object])
], OtpVerifyProvider);
//# sourceMappingURL=otp-verify.provider.js.map