import { Getter } from '@loopback/core';
import { BelongsToAccessor, DataObject, HasManyRepositoryFactory, HasOneRepositoryFactory, juggler } from '@loopback/repository';
import { Options } from '@loopback/repository/src/common-types';
import { DefaultUserUpdatableCrudRepository, EntityClass, IAuthUserWithPermissions, ILogger } from '@loopx/core';
import { Tenant, UserCredentials, UserTenant, UserTypes } from '../models';
import { OtpRepository } from './otp.repository';
import { TenantRepository } from './tenant.repository';
import { UserCredentialsRepository } from './user-credentials.repository';
import { UserTenantRepository } from './user-tenant.repository';
export declare class UserRepository<U extends UserTypes = UserTypes> extends DefaultUserUpdatableCrudRepository<U['Model'], U['ID'], U['Relations']> {
    getOtpRepository: Getter<OtpRepository>;
    protected tenantRepositoryGetter: Getter<TenantRepository>;
    protected userTenantRepositoryGetter: Getter<UserTenantRepository>;
    private readonly logger;
    readonly credentials: HasOneRepositoryFactory<UserCredentials, U['ID']>;
    readonly tenant: BelongsToAccessor<Tenant, U['ID']>;
    readonly userTenants: HasManyRepositoryFactory<UserTenant, U['ID']>;
    constructor(dataSource: juggler.DataSource, getUserCredsRepository: Getter<UserCredentialsRepository>, getOtpRepository: Getter<OtpRepository>, getCurrentUser: Getter<IAuthUserWithPermissions | undefined>, tenantRepositoryGetter: Getter<TenantRepository>, userTenantRepositoryGetter: Getter<UserTenantRepository>, logger: ILogger, entityClass?: EntityClass<U['Model']>);
    create(entity: DataObject<U['Model']>, options?: Options): Promise<U['Model']>;
    createWithoutCreds(entity: DataObject<U['Model']>, options?: Options): Promise<U['Model']>;
    verifyPassword(username: string, password: string): Promise<U['Model']>;
    updatePassword(username: string, password: string, newPassword: string): Promise<U['Model']>;
    changePassword(username: string, newPassword: string, oldPassword?: string): Promise<U['Model']>;
    updateLastLogin(userId: string): Promise<void>;
    firstTimeUser(userId: string): Promise<boolean>;
}
