"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationService = void 0;
const tslib_1 = require("tslib");
const length_1 = tslib_1.__importDefault(require("tily/array/length"));
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const core_2 = require("@loopx/core");
const errors_1 = require("../errors");
const repositories_1 = require("../repositories");
const email_1 = require("../utils/email");
const passwords_1 = require("../utils/passwords");
const phone_1 = require("../utils/phone");
let ValidationService = exports.ValidationService = class ValidationService {
    constructor(userRepository, logger) {
        this.userRepository = userRepository;
        this.logger = logger;
    }
    async validateUsername(username) {
        if ((0, length_1.default)(username) < 4) {
            throw new errors_1.ValidationErrors.UsernameTooShort({ data: { minLength: 4 } });
        }
        if ((0, length_1.default)(username) > 32) {
            throw new errors_1.ValidationErrors.UsernameTooLong({ data: { maxLength: 32 } });
        }
        const user = await this.userRepository.findOne({ where: { username }, fields: { id: true } });
        if (user) {
            throw new errors_1.ValidationErrors.UsernameExists();
        }
    }
    validatePassword(password) {
        const { verified, rules } = passwords_1.PasswordPolicies.Low.missing(password);
        if (!verified) {
            throw new errors_1.ValidationErrors.PasswordStrengthError({ data: rules });
        }
    }
    async validateEmail(email) {
        if (!(0, email_1.isValidEmail)(email)) {
            throw new errors_1.ValidationErrors.InvalidEmail();
        }
        const user = await this.userRepository.findOne({ where: { email }, fields: { id: true } });
        if (user) {
            throw new errors_1.ValidationErrors.EmailExists();
        }
    }
    async validatePhone(number) {
        if (!(0, phone_1.isValidPhoneNumber)(number)) {
            throw new errors_1.ValidationErrors.InvalidPhone();
        }
        const user = await this.userRepository.findOne({ where: { phone: number }, fields: { id: true } });
        if (user) {
            throw new errors_1.ValidationErrors.PhoneExists();
        }
    }
};
exports.ValidationService = ValidationService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.SINGLETON }),
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(1, (0, context_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.UserRepository, Object])
], ValidationService);
//# sourceMappingURL=validation.service.js.map